@@ -1,4 +1,3 @@
-# coding=utf-8
 from itertools import count
 from typing import Iterable
 
@@ -9,5 +8,5 @@ from oeis.registry import registry
 def buttered_croissant() -> Iterable[int]:
     """Layers of dough separated by butter in successive foldings of croissant dough."""
     yield 1  # special case
-    for n in count(start=1):
+    for n in count(start=1):  # pragma: no branch
         yield 1 + 2 * pow(3, n - 1)
