@@ -1,4 +1,3 @@
-# coding=utf-8
 from itertools import count
 from math import comb
 from typing import Iterable
@@ -10,5 +9,5 @@ from oeis.registry import registry
 def catalan() -> Iterable[int]:
     """Catalan numbers."""
     yield 1  # catalan(0)
-    for n in count(start=1):
+    for n in count(start=1):  # pragma: no branch
         yield comb(2 * n, n) - comb(2 * n, n - 1)
