@@ -1,4 +1,3 @@
-# coding=utf-8
 from itertools import count
 from typing import Iterable
 
@@ -9,6 +8,6 @@ from oeis.registry import registry
 def factorial() -> Iterable[int]:
     """Factorial numbers."""
     curr: int = 1
-    for n in count(start=1):
+    for n in count(start=1):  # pragma: no branch
         yield curr
         curr *= n
