@@ -1,4 +1,3 @@
-# coding=utf-8
 from itertools import count
 from typing import Iterable
 
@@ -10,5 +9,5 @@ def lazy_caterer() -> Iterable[int]:
     """Central polygonal numbers (the Lazy Caterer's sequence)."""
     yield 1  # special case
     yield 2  # special case
-    for i in count(start=2):
+    for i in count(start=2):  # pragma: no branch
         yield ((i * i) + i + 2) // 2
