@@ -1,15 +1,13 @@
-# coding=utf-8
 from itertools import count
 from typing import Iterable
 
 from oeis.registry import registry
-from oeis.utils import aliquot_sum
+from oeis.utils import is_perfect
 
 
 @registry.register("A000396")
 def perfect() -> Iterable[int]:
     """Perfect numbers."""
-    for n in count(start=1):
-        k: int = aliquot_sum(n)
-        if k == n:
+    for n in count(start=1):  # pragma: no branch
+        if is_perfect(n):
             yield n
