@@ -1,4 +1,3 @@
-# coding=utf-8
 """Create a thin wrapper around OEIS Registry."""
 from typing import Callable, Dict, Generic, Iterable, TypeVar
 
@@ -31,6 +30,8 @@ class OEISRegistry(Generic[T]):
             Args:
                 func: Sequence generator
             """
+            if identifier in self.sequences:
+                raise KeyError(f"Duplicate identifier found: {identifier}")
             self.sequences[identifier] = func
             return func
 
