@@ -1,4 +1,3 @@
-# coding=utf-8
 from itertools import count
 from typing import Iterable
 
@@ -8,5 +7,5 @@ from .registry import registry
 @registry.register("A003261")
 def woodall() -> Iterable[int]:
     """Woodall (or Riesel) numbers."""
-    for n in count(start=1):
-        yield n * (2 ** n) - 1
+    for n in count(start=1):  # pragma: no branch
+        yield n * (2**n) - 1
